 ;////////////////////////////////////////////////////////////////////////////
 ;
 ;  Copyright (C) Microsoft Corporation.  All Rights Reserved.
 ;
 ;  File:       d3dx9anim.h
 ;  Content:    D3DX mesh types and functions
 ;
 ;////////////////////////////////////////////////////////////////////////////
IFNDEF __D3DX9ANIM_H__
 ; {ADE2C06D-3747-4b9f-A514-3440B8284980}
sIID_ID3DXInterpolator	TEXTEQU	<{0ade2c06dh,03747h,04b9fh,(0a5h,014h,034h,040h,0b8h,028h,049h,080h}}>
 ; {6CAA71F8-0972-4cdb-A55B-43B968997515}
sIID_ID3DXKeyFrameInterpolator	TEXTEQU	<{06caa71f8h,0972h,04cdbh,(0a5h,05bh,043h,0b9h,068h,099h,075h,015h}}>
 ; {54B569AC-0AEF-473e-9704-3FEF317F64AB}
sIID_ID3DXAnimationSet	TEXTEQU	<{054b569ach,0aefh,0473eh,(097h,04h,03fh,0efh,031h,07fh,064h,0abh}}>
 ; {3A714D34-FF61-421e-909F-639F38356708}
sIID_ID3DXAnimationController	TEXTEQU	<{03a714d34h,0ff61h,0421eh,(090h,09fh,063h,09fh,038h,035h,067h,08h}}>
 ;----------------------------------------------------------------------------
 ; This enum defines the type of mesh data present in a MeshData structure
 ;----------------------------------------------------------------------------

;D3DXMESHDATATYPE	UNION
	D3DXMESHTYPE_MESH	EQU 0001h 	 ; normal ID3DXMesh data
	D3DXMESHTYPE_PMESH	EQU 0002h 	 ; Progressive Mesh - ID3DXPMesh
	D3DXMESHTYPE_PATCHMESH	EQU 0003h 	 ; Patch MEsh - ID3DXPatchMesh
	D3DXMESHTYPE_FORCE_DWORD	EQU 07fffffffh 	 ; force 32-bit size enum 
;D3DXMESHDATATYPE		ENDS


 ;----------------------------------------------------------------------------
 ; This struct encapsulates a the mesh data that can be present in a mesh
 ;   container.  The supported mesh types are pMesh, pPMesh, pPatchMesh
 ;   The valid way to access this is determined by the MeshType enum
 ;----------------------------------------------------------------------------

D3DXMESHDATA	STRUCT
	type1 DWORD ?
	union
	pMesh DWORD ?
	pPMesh DWORD ?
	pPatchMesh DWORD ?
	ENDS

D3DXMESHDATA		ENDS

 ;----------------------------------------------------------------------------
 ; This struct encapsulates a mesh object in a transformation frame
 ; hierarchy. The app can derive from this structure to add other app specific
 ; data to this
 ;----------------------------------------------------------------------------

D3DXMESHCONTAINER	STRUCT
	Name1 DWORD ?
	MeshData D3DXMESHDATA <> 
	pMaterials DWORD ?
	pEffects DWORD ?
	NumMaterials DWORD ?
	pAdjacency DWORD ?
	pSkinInfo DWORD ?
	pNextMeshContainer DWORD ?

D3DXMESHCONTAINER		ENDS

 ;----------------------------------------------------------------------------
 ; This struct is the encapsulates a transform frame in a transformation frame
 ; hierarchy. The app can derive from this structure to add other app specific
 ; data to this
 ;----------------------------------------------------------------------------

D3DXFRAME	STRUCT
	Name1 DWORD ?
	TransformationMatrix DWORD ? 
	pMeshContainer DWORD ?
	pFrameSibling DWORD ?
	pFrameFirstChild DWORD ?

D3DXFRAME		ENDS

INTERFACE	equ	<ID3DXAllocateHierarchy>
 ;----------------------------------------------------------------------------
 ; This interface is implemented by the application to allocate/free frame and
 ; mesh container objects. Methods on this are called during loading and
 ; destroying frame hierarchies
 ;----------------------------------------------------------------------------
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXAllocateHierarchy ////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ;----------------------------------------------------------------------------
 ; This interface is implemented by the application to load user data in a .X file
 ;   When user data is found, these callbacks will be used to allow the application
 ;   to load the data
 ;----------------------------------------------------------------------------
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXLoadUserData ////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ;----------------------------------------------------------------------------
 ; This interface is implemented by the application to save user data in a .X file
 ;   The callbacks are called for all data saved.  The user can then add any
 ;   child data objects to the object provided to the callback
 ;----------------------------------------------------------------------------
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXSaveUserData /////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;----------------------------------------------------------------------------
 ; D3DXLoadMeshHierarchyFromX:
 ; ---------------------------
 ; Loads the first frame hierarchy in a .X file.
 ;
 ; Parameters:
 ;  Filename
 ;      Name of the .X file
 ;  MeshOptions
 ;      Mesh creation options for meshes in the file (see d3dx9mesh.h)
 ;  pD3DDevice
 ;      D3D9 device on which meshes in the file are created in
 ;  pAlloc
 ;      Allocation interface used to allocate nodes of the frame hierarchy
 ;  pUserDataLoader
 ;      Application provided interface to allow loading of user data
 ;  ppFrameHierarchy
 ;      Returns root node pointer of the loaded frame hierarchy
 ;  ppAnimController
 ;      Returns pointer to an animation controller corresponding to animation
 ;		in the .X file. This is created with default max tracks and events
 ;
 ;----------------------------------------------------------------------------
;API
D3DXLoadMeshHierarchyFromXA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXLoadMeshHierarchyFromXW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXLoadMeshHierarchyFromX	equ	<D3DXLoadMeshHierarchyFromXW>
ELSE
D3DXLoadMeshHierarchyFromX	equ	<D3DXLoadMeshHierarchyFromXA>
ENDIF 
;API
D3DXLoadMeshHierarchyFromXInMemory PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXSaveMeshHierarchyToFile:
 ; ---------------------------
 ; Creates a .X file and saves the mesh hierarchy and corresponding animations
 ; in it
 ;
 ; Parameters:
 ;  Filename
 ;      Name of the .X file
 ;  XFormat
 ;      Format of the .X file (text or binary, compressed or not, etc)
 ;  pFrameRoot
 ;      Root node of the hierarchy to be saved
 ;  pAnimController
 ;      The animation mixer whose animation sets are to be stored
 ;  pUserDataSaver
 ;      Application provided interface to allow adding of user data to
 ;        data objects saved to .X file
 ;
 ;----------------------------------------------------------------------------
;API
D3DXSaveMeshHierarchyToFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXSaveMeshHierarchyToFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXSaveMeshHierarchyToFile	equ	<D3DXSaveMeshHierarchyToFileW>
ELSE
D3DXSaveMeshHierarchyToFile	equ	<D3DXSaveMeshHierarchyToFileA>
ENDIF 
 ;----------------------------------------------------------------------------
 ; D3DXFrameDestroy:
 ; -----------------
 ; Destroys the subtree of frames under the root, including the root
 ;
 ; Parameters:
 ;	pFrameRoot
 ;		Pointer to the root node
 ;  pAlloc
 ;      Allocation interface used to de-allocate nodes of the frame hierarchy
 ;
 ;----------------------------------------------------------------------------
;API
D3DXFrameDestroy PROTO :DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXFrameAppendChild:
 ; ---------------------
 ; Add a child frame to a frame
 ;
 ; Parameters:
 ;	pFrameParent
 ;		Pointer to the parent node
 ;  pFrameChild
 ;      Pointer to the child node
 ;
 ;----------------------------------------------------------------------------
;API
D3DXFrameAppendChild PROTO :DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXFrameFind:
 ; --------------
 ; Finds a frame with the given name.  Returns NULL if no frame found.
 ;
 ; Parameters:
 ;	pFrameRoot
 ;		Pointer to the root node
 ;  Name
 ;      Name of frame to find
 ;
 ;----------------------------------------------------------------------------
;API
D3DXFrameFind PROTO :DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXFrameRegisterNamedMatrices:
 ; --------------------------
 ; Finds all frames that have non-null names and registers each of those frame
 ; matrices to the given animation mixer
 ;
 ; Parameters:
 ;	pFrameRoot
 ;		Pointer to the root node
 ;	pAnimMixer
 ;		Pointer to the animation mixer where the matrices are registered
 ;
 ;----------------------------------------------------------------------------
;API
D3DXFrameRegisterNamedMatrices PROTO :DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXFrameNumNamedMatrices:
 ; --------------------------
 ; Counts number of frames in a subtree that have non-null names
 ;
 ; Parameters:
 ;	pFrameRoot
 ;		Pointer to the root node of the subtree
 ; Return Value:
 ;		Count of frames
 ;
 ;----------------------------------------------------------------------------
;API
D3DXFrameNumNamedMatrices PROTO :DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXFrameCalculateBoundingSphere:
 ; ---------------------------------
 ; Computes the bounding sphere of all the meshes in the frame hierarchy
 ;
 ; Parameters:
 ;	pFrameRoot
 ;		Pointer to the root node
 ;	pObjectCenter
 ;		Returns the center of the bounding sphere
 ;	pObjectRadius
 ;		Returns the radius of the bounding sphere
 ;
 ;----------------------------------------------------------------------------
;API
D3DXFrameCalculateBoundingSphere PROTO :DWORD ,:DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
INTERFACE	equ	<ID3DXInterpolator>
 ;----------------------------------------------------------------------------
 ; This interface defines a SRT (scale/rotate/translate) interpolator. This
 ; is an abstract interface. ID3DXKeyFrameInterpolator inherits from this.
 ; An application can implement this for custom SRT interpolator
 ;----------------------------------------------------------------------------
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXInterpolator /////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
;ID3DXInterpolator drive de : IUnknown
	STID3DXInterpolator	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetName                      	comethod1 ?
		GetPeriod                    	comethod1 ?
		GetSRT                       	comethod6 ?
		GetLastSRT                   	comethod4 ?
	STID3DXInterpolator	ENDS
 
ID3DXInterpolator MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXInterpolator PTR[edx]).>,<&Function,ppvID3DXInterpolator>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXInterpolator
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;----------------------------------------------------------------------------
 ; This structure describes a vector key for use in keyframe animation.
 ; It specifies a vector Value at a given Time. This is used for scale and
 ; translation keys
 ;----------------------------------------------------------------------------

D3DXKEY_VECTOR3	STRUCT
	Time REAL4 ?
	Value DWORD ?
D3DXKEY_VECTOR3		ENDS

 ;----------------------------------------------------------------------------
 ; This structure describes a quaternion key for use in keyframe animation.
 ; It specifies a quaternion Value at a given Time. This is used for rotation
 ; keys
 ;----------------------------------------------------------------------------

D3DXKEY_QUATERNION	STRUCT
	Time REAL4 ?
	Value DWORD ? 

D3DXKEY_QUATERNION		ENDS

INTERFACE	equ	<ID3DXKeyFrameInterpolator>
 ;----------------------------------------------------------------------------
 ; This interface implements an SRT (scale/rotate/translate) interpolator
 ; It takes a scattered set of keys and interpolates the transform for any
 ; given time
 ;----------------------------------------------------------------------------
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXKeyFrameInterpolator /////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
;ID3DXKeyFrameInterpolator drive de : ID3DXInterpolator
	STID3DXKeyFrameInterpolator	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetName                      	comethod1 ?
		GetPeriod                    	comethod1 ?
		GetSRT                       	comethod6 ?
		GetLastSRT                   	comethod4 ?
		GetNumScaleKeys              	comethod1 ?
		GetScaleKeys                 	comethod2 ?
		GetNumRotationKeys           	comethod1 ?
		GetRotationKeys              	comethod2 ?
		GetNumTranslationKeys        	comethod1 ?
		GetTranslationKeys           	comethod2 ?
		GetSourceTicksPerSecond      	comethod1 ?
	STID3DXKeyFrameInterpolator	ENDS
 
ID3DXKeyFrameInterpolator MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXKeyFrameInterpolator PTR[edx]).>,<&Function,ppvID3DXKeyFrameInterpolator>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXKeyFrameInterpolator
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;----------------------------------------------------------------------------
 ; This interface implements an set of interpolators. The set consists of
 ; interpolators for many nodes for the same animation.
 ;----------------------------------------------------------------------------
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXAnimationSet /////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
;ID3DXAnimationSet drive de : IUnknown
	STID3DXAnimationSet	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetName                      	comethod1 ?
		GetPeriod                    	comethod1 ?
		GetNumInterpolators          	comethod1 ?
		GetInterpolatorByIndex       	comethod3 ?
		GetInterpolatorByName        	comethod3 ?
	STID3DXAnimationSet	ENDS
 
ID3DXAnimationSet MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXAnimationSet PTR[edx]).>,<&Function,ppvID3DXAnimationSet>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXAnimationSet
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;----------------------------------------------------------------------------
 ; This structure describes an animation track. A track is a combination
 ;  of an animation set (stored separately) and mixing information.
 ;  the mixing information consists of the current position, speed, and blending
 ;  weight for the track.  The Flags field also specifies whether the track
 ;  is low or high priority.  Tracks with the same priority are blended together
 ;  and then the two resulting values are blended using the priority blend factor.
 ;----------------------------------------------------------------------------

D3DXTRACK_DESC	STRUCT
	Flags DWORD ?
	Weight REAL4 ?
	Speed REAL4 ?
	Enable DWORD ?
	AnimTime REAL8 ?

D3DXTRACK_DESC		ENDS

 ;----------------------------------------------------------------------------
 ; This enum defines the type of transtion performed on a event that transitions from one value to another
 ;----------------------------------------------------------------------------

;D3DXTRACKFLAG	UNION
	D3DXTF_LOWPRIORITY	EQU 0000h 	 ; This track should be blended with all low priority tracks before mixed with the high priority result
	D3DXTF_HIGHPRIORITY	EQU 0001h 	 ; This track should be blended with all high priority tracks before mixed with the low priority result
	D3DXTF_FORCE_DWORD	EQU 07fffffffh 	 ; force 32-bit size enum 
;D3DXTRACKFLAG		ENDS


 ;----------------------------------------------------------------------------
 ; This interface implements the main animation functionality. It connects
 ; animation sets with the transform frames that are being animated. Allows
 ; mixing multiple animations for blended animations or for transistions
 ; It adds also has methods to modify blending parameters over time to
 ; enable smooth transistions and other effects.
 ;----------------------------------------------------------------------------
 ;----------------------------------------------------------------------------
 ; This enum defines the type of transtion performed on a event that transitions from one value to another
 ;----------------------------------------------------------------------------

;D3DXTRANSITIONTYPE	UNION
	D3DXTRANSITION_LINEAR	EQU 0000h 	 ; Linear transition from one value to the next
	D3DXTRANSITION_EASEINEASEOUT	EQU 0001h 	 ; Ease-In Ease-Out spline transtion from one value to the next
	D3DXTRANSITION_FORCE_DWORD	EQU 07fffffffh 	 ; force 32-bit size enum 
;D3DXTRANSITIONTYPE		ENDS


 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXAnimationController //////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
;ID3DXAnimationController drive de : IUnknown
	STID3DXAnimationController	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		RegisterMatrix               	comethod3 ?
		GetNumAnimationSets          	comethod1 ?
		GetAnimationSet              	comethod3 ?
		RegisterAnimationSet         	comethod2 ?
		UnregisterAnimationSet       	comethod2 ?
		GetMaxNumTracks              	comethod1 ?
		GetTrackDesc                 	comethod3 ?
		SetTrackDesc                 	comethod3 ?
		GetTrackAnimationSet         	comethod3 ?
		SetTrackAnimationSet         	comethod3 ?
		SetTrackSpeed                	comethod3 ?
		SetTrackWeight               	comethod3 ?
		SetTrackAnimTime             	comethod4 ?
		SetTrackEnable               	comethod3 ?
		GetTime                      	comethod1 ?
		SetTime                      	comethod3 ?
		CloneAnimationController     	comethod6 ?
		GetMaxNumMatrices            	comethod1 ?
		GetMaxNumEvents              	comethod1 ?
		GetMaxNumAnimationSets       	comethod1 ?
		KeyTrackSpeed                	comethod8 ?
		KeyTrackWeight               	comethod8 ?
		KeyTrackAnimTime             	comethod6 ?
		KeyTrackEnable               	comethod5 ?
		GetPriorityBlend             	comethod1 ?
		SetPriorityBlend             	comethod2 ?
		KeyPriorityBlend             	comethod7 ?
	STID3DXAnimationController	ENDS
 
ID3DXAnimationController MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXAnimationController PTR[edx]).>,<&Function,ppvID3DXAnimationController>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXAnimationController
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;----------------------------------------------------------------------------
 ; D3DXCreateKeyFrameInterpolator:
 ; -------------------------------
 ; Creates a SRT key frame interpolator object from the given set of keys
 ;
 ; Parameters:
 ;	ScaleKeys
 ;		Array of scale key vectors
 ;	NumScaleKeys
 ;		Num elements in ScaleKeys array
 ;	RotationKeys
 ;		Array of rotation key quternions
 ;	NumRotationKeys
 ;		Num elements in RotationKeys array
 ;	TranslateKeys
 ;		Array of translation key vectors
 ;	NumTranslateKeys
 ;		Num elements in TranslateKeys array
 ;	ScaleInputTimeBy
 ;		All key times are scaled by this factor
 ;	ppNewInterpolator
 ;		Returns the keyframe interpolator interface
 ;
 ;----------------------------------------------------------------------------
;API
D3DXCreateKeyFrameInterpolator PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXCreateAnimationSet:
 ; -----------------------
 ; Creates an animtions set interface given a set of interpolators
 ;
 ; Parameters:
 ;	Name
 ;		Name of the animation set
 ;	pInterpolators
 ;		Array of interpolators
 ;	NumInterpolators
 ;		Num elements in the pInterpolators array
 ;	ppAnimSet
 ;		Returns the animation set interface
 ;
 ;-----------------------------------------------------------------------------
;API
D3DXCreateAnimationSet PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXCreateAnimationController:
 ; -------------------------
 ; Creates an animtion mixer object
 ;
 ; Parameters:
 ;	MaxNumMatrices
 ;		The upper limit for the number of matrices that can be animated by the
 ;		the object
 ;	MaxNumAnimationSets
 ;		The upper limit of the number of animation sets that can be played by
 ;		the object
 ;	MaxNumTracks
 ;		The upper limit of the number of animation sets that can be blended at
 ;		any time.
 ;	MaxNumEvents
 ;		The upper limit of the number of outstanding events that can be
 ;		scheduled at once.
 ;	ppAnimController
 ;		Returns the animation controller interface
 ;
 ;-----------------------------------------------------------------------------
;API
D3DXCreateAnimationController PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
ENDIF  ;__D3DX9ANIM_H__
