 ;/////////////////////////////////////////////////////////////////////////
 ;
 ;  Copyright (C) Microsoft Corporation.  All Rights Reserved.
 ;
 ;  File:       d3dx9core.h
 ;  Content:    D3DX core types and functions
 ;
 ;/////////////////////////////////////////////////////////////////////////
IFNDEF __D3DX9_H__
INCLUDE d3dx9.INC
ENDIF
IFNDEF __D3DX9CORE_H__
 ;/////////////////////////////////////////////////////////////////////////
 ; D3DX_SDK_VERSION:
 ; -----------------
 ; This identifier is passed to D3DXCheckVersion in order to ensure that an
 ; application was built against the correct header files and lib files.
 ; This number is incremented whenever a header (or other) change would
 ; require applications to be rebuilt. If the version doesn't match,
 ; D3DXCreateVersion will return FALSE. (The number itself has no meaning.)
 ;/////////////////////////////////////////////////////////////////////////
D3DX_VERSION	equ	<00900h>
D3DX_SDK_VERSION	equ	<9>
IFDEF __cplusplus
ENDIF  ;__cplusplus
;API
D3DXCheckVersion PROTO :DWORD ,:DWORD 
 ;/////////////////////////////////////////////////////////////////////////
 ; D3DXGetDriverLevel:
 ;    Returns driver version information:
 ;
 ;    700 - DX7 level driver
 ;    800 - DX8 level driver
 ;    900 - DX9 level driver
 ;/////////////////////////////////////////////////////////////////////////
;API
D3DXGetDriverLevel PROTO :DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;/////////////////////////////////////////////////////////////////////////
 ; ID3DXBuffer:
 ; ------------
 ; The buffer object is used by D3DX to return arbitrary size data.
 ;
 ; GetBufferPointer -
 ;    Returns a pointer to the beginning of the buffer.
 ;
 ; GetBufferSize -
 ;    Returns the size of the buffer, in bytes.
 ;/////////////////////////////////////////////////////////////////////////
 ; {932E6A7E-C68E-45dd-A7BF-53D19C86DB1F}
sIID_ID3DXBuffer	TEXTEQU	<{0932e6a7eh,0c68eh,045ddh,(0a7h,0bfh,053h,0d1h,09ch,086h,0dbh,01fh}}>
INTERFACE	equ	<ID3DXBuffer>
;ID3DXBuffer drive de : IUnknown
	STID3DXBuffer	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetBufferPointer             	comethod1 ?
		GetBufferSize                	comethod1 ?
	STID3DXBuffer	ENDS
 
ID3DXBuffer MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXBuffer PTR[edx]).>,<&Function,ppvID3DXBuffer>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXBuffer
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;/////////////////////////////////////////////////////////////////////////
 ; ID3DXFont:
 ; ----------
 ; Font objects contain the textures and resources needed to render
 ; a specific font on a specific device.
 ;
 ; Begin -
 ;    Prepartes device for drawing text.  This is optional.. if DrawText
 ;    is called outside of Begin/End, it will call Begin and End for you.
 ;
 ; DrawText -
 ;    Draws formatted text on a D3D device.  Some parameters are
 ;    surprisingly similar to those of GDI's DrawText function.  See GDI
 ;    documentation for a detailed description of these parameters.
 ;
 ; End -
 ;    Restores device state to how it was when Begin was called.
 ;
 ; OnLostDevice, OnResetDevice -
 ;    Call OnLostDevice() on this object before calling Reset() on the
 ;    device, so that this object can release any stateblocks and video
 ;    memory resources.  After Reset(), the call OnResetDevice().
 ;
 ;/////////////////////////////////////////////////////////////////////////
 ; {4AAE6B4D-D15F-4909-B09F-8D6AA34AC06B}
sIID_ID3DXFont	TEXTEQU	<{04aae6b4dh,0d15fh,04909h,(0b0h,09fh,08dh,06ah,0a3h,04ah,0c0h,06bh}}>
INTERFACE	equ	<ID3DXFont>
;ID3DXFont drive de : IUnknown
	STID3DXFont	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDevice                    	comethod2 ?
		GetLogFont                   	comethod2 ?
		Begin                        	comethod1 ?
		DrawTextA                    	comethod6 ?
		DrawTextW                    	comethod6 ?
		End1                          	comethod1 ?
		OnLostDevice                 	comethod1 ?
		OnResetDevice                	comethod1 ?
	STID3DXFont	ENDS
 
ID3DXFont MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXFont PTR[edx]).>,<&Function,ppvID3DXFont>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXFont
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
IFNDEF DrawText
IFDEF UNICODE
DrawText	equ	<DrawTextW>
ELSE
DrawText	equ	<DrawTextA>
ENDIF 
ENDIF 
IFDEF __cplusplus
ENDIF  ;__cplusplus
;API
D3DXCreateFont PROTO :DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateFontIndirect PROTO :DWORD ,:DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;/////////////////////////////////////////////////////////////////////////
 ; ID3DXSprite:
 ; ------------
 ; This object intends to provide an easy way to drawing sprites using D3D.
 ;
 ; Begin -
 ;    Prepares device for drawing sprites
 ;
 ; Draw, DrawAffine, DrawTransform -
 ;    Draws a sprite in screen-space.  Before transformation, the sprite is
 ;    the size of SrcRect, with its top-left corner at the origin (0,0).
 ;    The color and alpha channels are modulated by Color.
 ;
 ; End -
 ;     Restores device state to how it was when Begin was called.
 ;
 ; OnLostDevice, OnResetDevice -
 ;    Call OnLostDevice() on this object before calling Reset() on the
 ;    device, so that this object can release any stateblocks and video
 ;    memory resources.  After Reset(), the call OnResetDevice().
 ;/////////////////////////////////////////////////////////////////////////
 ; {B07EC84A-8D35-4e86-A9A0-8DFF21D71075}
sIID_ID3DXSprite	TEXTEQU	<{0b07ec84ah,08d35h,04e86h,(0a9h,0a0h,08dh,0ffh,021h,0d7h,010h,075h}}>
INTERFACE	equ	<ID3DXSprite>
;ID3DXSprite drive de : IUnknown
	STID3DXSprite	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDevice                    	comethod2 ?
		Begin                        	comethod1 ?
		Draw                         	comethod8 ?
		DrawTransform                	comethod5 ?
		End1                          	comethod1 ?
		OnLostDevice                 	comethod1 ?
		OnResetDevice                	comethod1 ?
	STID3DXSprite	ENDS
 
ID3DXSprite MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXSprite PTR[edx]).>,<&Function,ppvID3DXSprite>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXSprite
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
IFDEF __cplusplus
ENDIF  ;__cplusplus
;API
D3DXCreateSprite PROTO :DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;/////////////////////////////////////////////////////////////////////////
 ; ID3DXRenderToSurface:
 ; ---------------------
 ; This object abstracts rendering to surfaces.  These surfaces do not
 ; necessarily need to be render targets.  If they are not, a compatible
 ; render target is used, and the result copied into surface at end scene.
 ;
 ; BeginScene, EndScene -
 ;    Call BeginScene() and EndScene() at the beginning and ending of your
 ;    scene.  These calls will setup and restore render targets, viewports,
 ;    etc..
 ;
 ; OnLostDevice, OnResetDevice -
 ;    Call OnLostDevice() on this object before calling Reset() on the
 ;    device, so that this object can release any stateblocks and video
 ;    memory resources.  After Reset(), the call OnResetDevice().
 ;/////////////////////////////////////////////////////////////////////////

D3DXRTS_DESC	STRUCT
	Width1 DWORD ?
	Height DWORD ?
	Format DWORD ? 
	DepthStencil DWORD ?
	DepthStencilFormat DWORD ? 

D3DXRTS_DESC		ENDS

 ; {0D014791-8863-4c2c-A1C0-02F3E0C0B653}
sIID_ID3DXRenderToSurface	TEXTEQU	<{0d014791h,08863h,04c2ch,(0a1h,0c0h,02h,0f3h,0e0h,0c0h,0b6h,053h}}>
INTERFACE	equ	<ID3DXRenderToSurface>
;ID3DXRenderToSurface drive de : IUnknown
	STID3DXRenderToSurface	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDevice                    	comethod2 ?
		GetDesc                      	comethod2 ?
		BeginScene                   	comethod3 ?
		EndScene                     	comethod2 ?
		OnLostDevice                 	comethod1 ?
		OnResetDevice                	comethod1 ?
	STID3DXRenderToSurface	ENDS
 
ID3DXRenderToSurface MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXRenderToSurface PTR[edx]).>,<&Function,ppvID3DXRenderToSurface>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXRenderToSurface
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
IFDEF __cplusplus
ENDIF  ;__cplusplus
;API
D3DXCreateRenderToSurface PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;/////////////////////////////////////////////////////////////////////////
 ; ID3DXRenderToEnvMap:
 ; --------------------
 ; This object abstracts rendering to environment maps.  These surfaces
 ; do not necessarily need to be render targets.  If they are not, a
 ; compatible render target is used, and the result copied into the
 ; environment map at end scene.
 ;
 ; BeginCube, BeginSphere, BeginHemisphere, BeginParabolic -
 ;    This function initiates the rendering of the environment map.  As
 ;    parameters, you pass the textures in which will get filled in with
 ;    the resulting environment map.
 ;
 ; Face -
 ;    Call this function to initiate the drawing of each face.  For each
 ;    environment map, you will call this six times.. once for each face
 ;    in D3DCUBEMAP_FACES.
 ;
 ; End -
 ;    This will restore all render targets, and if needed compose all the
 ;    rendered faces into the environment map surfaces.
 ;
 ; OnLostDevice, OnResetDevice -
 ;    Call OnLostDevice() on this object before calling Reset() on the
 ;    device, so that this object can release any stateblocks and video
 ;    memory resources.  After Reset(), the call OnResetDevice().
 ;/////////////////////////////////////////////////////////////////////////

D3DXRTE_DESC	STRUCT
	size1 DWORD ?
	MipLevels DWORD ?
	Format DWORD ? 
	DepthStencil DWORD ?
	DepthStencilFormat DWORD ? 

D3DXRTE_DESC		ENDS

 ; {1561135E-BC78-495b-8586-94EA537BD557}
sIID_ID3DXRenderToEnvMap	TEXTEQU	<{01561135eh,0bc78h,0495bh,(085h,086h,094h,0eah,053h,07bh,0d5h,057h}}>
INTERFACE	equ	<ID3DXRenderToEnvMap>
;ID3DXRenderToEnvMap drive de : IUnknown
	STID3DXRenderToEnvMap	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDevice                    	comethod2 ?
		GetDesc                      	comethod2 ?
		BeginCube                    	comethod2 ?
		BeginSphere                  	comethod2 ?
		BeginHemisphere              	comethod3 ?
		BeginParabolic               	comethod3 ?
		Face                         	comethod3 ?
		End1                          	comethod2 ?
		OnLostDevice                 	comethod1 ?
		OnResetDevice                	comethod1 ?
	STID3DXRenderToEnvMap	ENDS
 
ID3DXRenderToEnvMap MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXRenderToEnvMap PTR[edx]).>,<&Function,ppvID3DXRenderToEnvMap>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXRenderToEnvMap
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
IFDEF __cplusplus
ENDIF  ;__cplusplus
;API
D3DXCreateRenderToEnvMap PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;/////////////////////////////////////////////////////////////////////////
 ; ID3DXLine:
 ; ------------
 ; This object intends to provide an easy way to draw lines using D3D.
 ;
 ; Begin -
 ;    Prepares device for drawing lines
 ;
 ; Draw -
 ;    Draws a line strip in screen-space.
 ;    Input is in the form of a array defining points on the line strip. of D3DXVECTOR2
 ;
 ; DrawTransform -
 ;    Draws a line in screen-space with a specified input transformation matrix.
 ;
 ; End -
 ;     Restores device state to how it was when Begin was called.
 ;
 ; SetPattern -
 ;     Applies a stipple pattern to the line.  Input is one 32-bit
 ;     DWORD which describes the stipple pattern. 1 is opaque, 0 is
 ;     transparent.
 ;
 ; SetPatternScale -
 ;     Stretches the stipple pattern in the u direction.  Input is one
 ;     floating-point value.  0.0f is no scaling, whereas 1.0f doubles
 ;     the length of the stipple pattern.
 ;
 ; SetWidth -
 ;     Specifies the thickness of the line in the v direction.  Input is
 ;     one floating-point value.
 ;
 ; SetAntialias -
 ;     Toggles line antialiasing.  Input is a BOOL.
 ;     TRUE  = Antialiasing on.
 ;     FALSE = Antialiasing off.
 ;
 ; SetGLLines -
 ;     Toggles non-antialiased OpenGL line emulation.  Input is a BOOL.
 ;     TRUE  = OpenGL line emulation on.
 ;     FALSE = OpenGL line emulation off.
 ;
 ; OpenGL line:     Regular line:
 ;   *\                *\
 ;   | \              /  \
 ;   |  \            *\   \
 ;   *\  \             \   \
 ;     \  \             \   \
 ;      \  *             \   *
 ;       \ |              \ /
 ;        \|               *
 ;         *
 ;
 ; OnLostDevice, OnResetDevice -
 ;    Call OnLostDevice() on this object before calling Reset() on the
 ;    device, so that this object can release any stateblocks and video
 ;    memory resources.  After Reset(), the call OnResetDevice().
 ;/////////////////////////////////////////////////////////////////////////
 ; {72CE4D70-CC40-4143-A896-32E50AD2EF35}
sIID_ID3DXLine	TEXTEQU	<{072ce4d70h,0cc40h,04143h,(0a8h,096h,032h,0e5h,0ah,0d2h,0efh,035h}}>
INTERFACE	equ	<ID3DXLine>
;ID3DXLine drive de : IUnknown
	STID3DXLine	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDevice                    	comethod2 ?
		Begin                        	comethod1 ?
		Draw                         	comethod4 ?
		DrawTransform                	comethod5 ?
		SetPattern                   	comethod2 ?
		GetPattern                   	comethod1 ?
		SetPatternScale              	comethod2 ?
		GetPatternScale              	comethod1 ?
		SetWidth                     	comethod2 ?
		GetWidth                     	comethod1 ?
		SetAntialias                 	comethod2 ?
		GetAntialias                 	comethod1 ?
		SetGLLines                   	comethod2 ?
		GetGLLines                   	comethod1 ?
		End1                          	comethod1 ?
		OnLostDevice                 	comethod1 ?
		OnResetDevice                	comethod1 ?
	STID3DXLine	ENDS
 
ID3DXLine MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXLine PTR[edx]).>,<&Function,ppvID3DXLine>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXLine
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
IFDEF __cplusplus
ENDIF  ;__cplusplus
;API
D3DXCreateLine PROTO :DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
ENDIF  ;__D3DX9CORE_H__
