 ;////////////////////////////////////////////////////////////////////////////
 ;
 ;  Copyright (c) Microsoft Corporation.  All rights reserved.
 ;
 ;  File:       d3dx9effect.h
 ;  Content:    D3DX effect types and Shaders
 ;
 ;////////////////////////////////////////////////////////////////////////////
IFNDEF __D3DX9_H__
INCLUDE d3dx9.INC
ENDIF

IFNDEF __D3DX9EFFECT_H__
 ;----------------------------------------------------------------------------
 ; D3DXFX_DONOTSAVESTATE
 ;   This flag is used as a parameter to ID3DXEffect::Begin().  When this flag
 ;   is specified, device state is not saved and restored in Begin/End.
 ; D3DXFX_DONOTSAVESHADERSTATE
 ;   This flag is used as a parameter to ID3DXEffect::Begin().  When this flag
 ;   is specified, shader device state is not saved and restored in Begin/End.
 ;   This includes pixel/vertex shaders and shader constants
 ;----------------------------------------------------------------------------
D3DXFX_DONOTSAVESTATE	equ	<1 SHL  0>
D3DXFX_DONOTSAVESHADERSTATE	equ	<1 SHL  1>
 ;----------------------------------------------------------------------------
 ; D3DX_PARAMETER_SHARED
 ;   Indicates that the value of a parameter will be shared with all effects
 ;   which share the same namespace.  Changing the value in one effect will
 ;   change it in all.
 ;
 ; D3DX_PARAMETER_LITERAL
 ;   Indicates that the value of this parameter can be treated as literal.
 ;   Literal parameters can be marked when the effect is compiled, and their
 ;   cannot be changed after the effect is compiled.  Shared parameters cannot
 ;   be literal.
 ;----------------------------------------------------------------------------
D3DX_PARAMETER_SHARED	equ	<1 SHL  0>
D3DX_PARAMETER_LITERAL	equ	<1 SHL  1>
D3DX_PARAMETER_ANNOTATION	equ	<1 SHL  2>
 ;----------------------------------------------------------------------------
 ; D3DXEFFECT_DESC:
 ;----------------------------------------------------------------------------

D3DXEFFECT_DESC	STRUCT
	Creator DWORD ?  ; Creator string
	Parameters DWORD ?  ; Number of parameters
	Techniques DWORD ?  ; Number of techniques
	Functions DWORD ?  ; Number of function entrypoints

D3DXEFFECT_DESC		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXPARAMETER_DESC:
 ;----------------------------------------------------------------------------

D3DXPARAMETER_DESC	STRUCT
	Name1 DWORD ?  ; Parameter name
	Semantic DWORD ?  ; Parameter semantic
	Class DWORD ?   ; Class
	type1 DWORD ?   ; Component type
	Rows DWORD ?  ; Number of rows
	Columns DWORD ?  ; Number of columns
	Elements DWORD ?  ; Number of array elements
	Annotations DWORD ?  ; Number of annotations
	StructMembers DWORD ?  ; Number of structure member sub-parameters
	Flags DWORD ?  ; D3DX_PARAMETER_* flags
	Bytes DWORD ?  ; Parameter size, in bytes

D3DXPARAMETER_DESC		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXTECHNIQUE_DESC:
 ;----------------------------------------------------------------------------

D3DXTECHNIQUE_DESC	STRUCT
	Name1 DWORD ?  ; Technique name
	Passes DWORD ?  ; Number of passes
	Annotations DWORD ?  ; Number of annotations

D3DXTECHNIQUE_DESC		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXPASS_DESC:
 ;----------------------------------------------------------------------------

D3DXPASS_DESC	STRUCT
	Name1 DWORD ?  ; Pass name
	Annotations DWORD ?  ; Number of annotations
	VSVersion DWORD ?  ; Vertex shader version (0 in case of NULL shader)
	PSVersion DWORD ?  ; Pixel shader version (0 in case of NULL shader)
	VSSemanticsUsed DWORD ?
	VSSemantics D3DXSEMANTIC MAXD3DDECLLENGTH dup (<?>)
	PSSemanticsUsed DWORD ?
	PSSemantics D3DXSEMANTIC MAXD3DDECLLENGTH dup (<?>)
	PSSamplersUsed DWORD ?
	PSSamplers DWORD 16 dup (?)

D3DXPASS_DESC		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXFUNCTION_DESC:
 ;----------------------------------------------------------------------------

D3DXFUNCTION_DESC	STRUCT
	Name1 DWORD ?  ; Function name
	Annotations DWORD ?  ; Number of annotations

D3DXFUNCTION_DESC		ENDS

 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXEffectPool ///////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ; {53CA7768-C0D0-4664-8E79-D156E4F5B7E0}
sIID_ID3DXEffectPool	TEXTEQU	<{053ca7768h,0c0d0h,04664h,(08eh,079h,0d1h,056h,0e4h,0f5h,0b7h,0e0h}}>
INTERFACE	equ	<ID3DXEffectPool>
;ID3DXEffectPool drive de : IUnknown
	STID3DXEffectPool	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
	STID3DXEffectPool	ENDS
 
ID3DXEffectPool MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXEffectPool PTR[edx]).>,<&Function,ppvID3DXEffectPool>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXEffectPool
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXBaseEffect ///////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ; {804EF574-CCC1-4bf6-B06A-B1404ABDEADE}
sIID_ID3DXBaseEffect	TEXTEQU	<{0804ef574h,0ccc1h,04bf6h,(0b0h,06ah,0b1h,040h,04ah,0bdh,0eah,0deh}}>
INTERFACE	equ	<ID3DXBaseEffect>
;ID3DXBaseEffect drive de : IUnknown
	STID3DXBaseEffect	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDesc                      	comethod2 ?
		GetParameterDesc             	comethod3 ?
		GetTechniqueDesc             	comethod3 ?
		GetPassDesc                  	comethod3 ?
		GetFunctionDesc              	comethod3 ?
		GetParameter                 	comethod3 ?
		GetParameterByName           	comethod3 ?
		GetParameterBySemantic       	comethod3 ?
		GetParameterElement          	comethod3 ?
		GetTechnique                 	comethod2 ?
		GetTechniqueByName           	comethod2 ?
		GetPass                      	comethod3 ?
		GetPassByName                	comethod3 ?
		GetFunction                  	comethod2 ?
		GetFunctionByName            	comethod2 ?
		GetAnnotation                	comethod3 ?
		GetAnnotationByName          	comethod3 ?
		SetValue                     	comethod4 ?
		GetValue                     	comethod4 ?
		SetBool                      	comethod3 ?
		GetBool                      	comethod3 ?
		SetBoolArray                 	comethod4 ?
		GetBoolArray                 	comethod4 ?
		SetInt                       	comethod3 ?
		GetInt                       	comethod3 ?
		SetIntArray                  	comethod4 ?
		GetIntArray                  	comethod4 ?
		SetFloat                     	comethod3 ?
		GetFloat                     	comethod3 ?
		SetFloatArray                	comethod4 ?
		GetFloatArray                	comethod4 ?
		SetVector                    	comethod3 ?
		GetVector                    	comethod3 ?
		SetVectorArray               	comethod4 ?
		GetVectorArray               	comethod4 ?
		SetMatrix                    	comethod3 ?
		GetMatrix                    	comethod3 ?
		SetMatrixArray               	comethod4 ?
		GetMatrixArray               	comethod4 ?
		SetMatrixPointerArray        	comethod4 ?
		GetMatrixPointerArray        	comethod4 ?
		SetMatrixTranspose           	comethod3 ?
		GetMatrixTranspose           	comethod3 ?
		SetMatrixTransposeArray      	comethod4 ?
		GetMatrixTransposeArray      	comethod4 ?
		SetMatrixTransposePointerArray 	comethod4 ?
		GetMatrixTransposePointerArray 	comethod4 ?
		SetString                    	comethod3 ?
		GetString                    	comethod3 ?
		SetTexture                   	comethod3 ?
		GetTexture                   	comethod3 ?
		SetPixelShader               	comethod3 ?
		GetPixelShader               	comethod3 ?
		SetVertexShader              	comethod3 ?
		GetVertexShader              	comethod3 ?
	STID3DXBaseEffect	ENDS
 
ID3DXBaseEffect MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXBaseEffect PTR[edx]).>,<&Function,ppvID3DXBaseEffect>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXBaseEffect
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXEffect ///////////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ; {B589B04A-293D-4516-AF0B-3D7DBCF5AC54}
sIID_ID3DXEffect	TEXTEQU	<{0b589b04ah,0293dh,04516h,(0afh,0bh,03dh,07dh,0bch,0f5h,0ach,054h}}>
INTERFACE	equ	<ID3DXEffect>
;ID3DXEffect drive de : ID3DXBaseEffect
	STID3DXEffect	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDesc                      	comethod2 ?
		GetParameterDesc             	comethod3 ?
		GetTechniqueDesc             	comethod3 ?
		GetPassDesc                  	comethod3 ?
		GetFunctionDesc              	comethod3 ?
		GetParameter                 	comethod3 ?
		GetParameterByName           	comethod3 ?
		GetParameterBySemantic       	comethod3 ?
		GetParameterElement          	comethod3 ?
		GetTechnique                 	comethod2 ?
		GetTechniqueByName           	comethod2 ?
		GetPass                      	comethod3 ?
		GetPassByName                	comethod3 ?
		GetFunction                  	comethod2 ?
		GetFunctionByName            	comethod2 ?
		GetAnnotation                	comethod3 ?
		GetAnnotationByName          	comethod3 ?
		SetValue                     	comethod4 ?
		GetValue                     	comethod4 ?
		SetBool                      	comethod3 ?
		GetBool                      	comethod3 ?
		SetBoolArray                 	comethod4 ?
		GetBoolArray                 	comethod4 ?
		SetInt                       	comethod3 ?
		GetInt                       	comethod3 ?
		SetIntArray                  	comethod4 ?
		GetIntArray                  	comethod4 ?
		SetFloat                     	comethod3 ?
		GetFloat                     	comethod3 ?
		SetFloatArray                	comethod4 ?
		GetFloatArray                	comethod4 ?
		SetVector                    	comethod3 ?
		GetVector                    	comethod3 ?
		SetVectorArray               	comethod4 ?
		GetVectorArray               	comethod4 ?
		SetMatrix                    	comethod3 ?
		GetMatrix                    	comethod3 ?
		SetMatrixArray               	comethod4 ?
		GetMatrixArray               	comethod4 ?
		SetMatrixPointerArray        	comethod4 ?
		GetMatrixPointerArray        	comethod4 ?
		SetMatrixTranspose           	comethod3 ?
		GetMatrixTranspose           	comethod3 ?
		SetMatrixTransposeArray      	comethod4 ?
		GetMatrixTransposeArray      	comethod4 ?
		SetMatrixTransposePointerArray 	comethod4 ?
		GetMatrixTransposePointerArray 	comethod4 ?
		SetString                    	comethod3 ?
		GetString                    	comethod3 ?
		SetTexture                   	comethod3 ?
		GetTexture                   	comethod3 ?
		SetPixelShader               	comethod3 ?
		GetPixelShader               	comethod3 ?
		SetVertexShader              	comethod3 ?
		GetVertexShader              	comethod3 ?
		GetPool                      	comethod2 ?
		SetTechnique                 	comethod2 ?
		GetCurrentTechnique          	comethod1 ?
		ValidateTechnique            	comethod2 ?
		FindNextValidTechnique       	comethod3 ?
		IsParameterUsed              	comethod3 ?
		Begin                        	comethod3 ?
		Pass                         	comethod2 ?
		End1                          	comethod1 ?
		GetDevice                    	comethod2 ?
		OnLostDevice                 	comethod1 ?
		OnResetDevice                	comethod1 ?
		CloneEffect                  	comethod3 ?
	STID3DXEffect	ENDS
 
ID3DXEffect MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXEffect PTR[edx]).>,<&Function,ppvID3DXEffect>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXEffect
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;////////////////////////////////////////////////////////////////////////////
 ; ID3DXEffectCompiler ///////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ; {F8EE90D3-FCC6-4f14-8AE8-6374AE968E33}
sIID_ID3DXEffectCompiler	TEXTEQU	<{0f8ee90d3h,0fcc6h,04f14h,(08ah,0e8h,063h,074h,0aeh,096h,08eh,033h}}>
INTERFACE	equ	<ID3DXEffectCompiler>
;ID3DXEffectCompiler drive de : ID3DXBaseEffect
	STID3DXEffectCompiler	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDesc                      	comethod2 ?
		GetParameterDesc             	comethod3 ?
		GetTechniqueDesc             	comethod3 ?
		GetPassDesc                  	comethod3 ?
		GetFunctionDesc              	comethod3 ?
		GetParameter                 	comethod3 ?
		GetParameterByName           	comethod3 ?
		GetParameterBySemantic       	comethod3 ?
		GetParameterElement          	comethod3 ?
		GetTechnique                 	comethod2 ?
		GetTechniqueByName           	comethod2 ?
		GetPass                      	comethod3 ?
		GetPassByName                	comethod3 ?
		GetFunction                  	comethod2 ?
		GetFunctionByName            	comethod2 ?
		GetAnnotation                	comethod3 ?
		GetAnnotationByName          	comethod3 ?
		SetValue                     	comethod4 ?
		GetValue                     	comethod4 ?
		SetBool                      	comethod3 ?
		GetBool                      	comethod3 ?
		SetBoolArray                 	comethod4 ?
		GetBoolArray                 	comethod4 ?
		SetInt                       	comethod3 ?
		GetInt                       	comethod3 ?
		SetIntArray                  	comethod4 ?
		GetIntArray                  	comethod4 ?
		SetFloat                     	comethod3 ?
		GetFloat                     	comethod3 ?
		SetFloatArray                	comethod4 ?
		GetFloatArray                	comethod4 ?
		SetVector                    	comethod3 ?
		GetVector                    	comethod3 ?
		SetVectorArray               	comethod4 ?
		GetVectorArray               	comethod4 ?
		SetMatrix                    	comethod3 ?
		GetMatrix                    	comethod3 ?
		SetMatrixArray               	comethod4 ?
		GetMatrixArray               	comethod4 ?
		SetMatrixPointerArray        	comethod4 ?
		GetMatrixPointerArray        	comethod4 ?
		SetMatrixTranspose           	comethod3 ?
		GetMatrixTranspose           	comethod3 ?
		SetMatrixTransposeArray      	comethod4 ?
		GetMatrixTransposeArray      	comethod4 ?
		SetMatrixTransposePointerArray 	comethod4 ?
		GetMatrixTransposePointerArray 	comethod4 ?
		SetString                    	comethod3 ?
		GetString                    	comethod3 ?
		SetTexture                   	comethod3 ?
		GetTexture                   	comethod3 ?
		SetPixelShader               	comethod3 ?
		GetPixelShader               	comethod3 ?
		SetVertexShader              	comethod3 ?
		GetVertexShader              	comethod3 ?
		SetLiteral                   	comethod3 ?
		GetLiteral                   	comethod3 ?
		CompileEffect                	comethod4 ?
		CompileShader                	comethod7 ?
	STID3DXEffectCompiler	ENDS
 
ID3DXEffectCompiler MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXEffectCompiler PTR[edx]).>,<&Function,ppvID3DXEffectCompiler>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXEffectCompiler
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;////////////////////////////////////////////////////////////////////////////
 ; APIs //////////////////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;----------------------------------------------------------------------------
 ; D3DXCreateEffectPool:
 ; ---------------------
 ; Creates an effect pool.  Pools are used for sharing parameters between
 ; multiple effects.  For all effects within a pool, shared parameters of the
 ; same name all share the same value.
 ;
 ; Parameters:
 ;  ppPool
 ;      Returns the created pool.
 ;----------------------------------------------------------------------------
;API
D3DXCreateEffectPool PROTO :DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXCreateEffect:
 ; -----------------
 ; Creates an effect from an ascii or binary effect description.
 ;
 ; Parameters:
 ;  pDevice
 ;      Pointer of the device on which to create the effect
 ;  pSrcFile
 ;      Name of the file containing the effect description
 ;  hSrcModule
 ;      Module handle. if NULL, current module will be used.
 ;  pSrcResource
 ;      Resource name in module
 ;  pSrcData
 ;      Pointer to effect description
 ;  SrcDataSize
 ;      Size of the effect description in bytes
 ;  pDefines
 ;      Optional NULL-terminated array of preprocessor macro definitions.
 ;  pInclude
 ;      Optional interface pointer to use for handling #include directives.
 ;      If this parameter is NULL, #includes will be honored when compiling
 ;      from file, and will error when compiling from resource or memory.
 ;  pPool
 ;      Pointer to ID3DXEffectPool object to use for shared parameters.
 ;      If NULL, no parameters will be shared.
 ;  ppEffect
 ;      Returns a buffer containing created effect.
 ;  ppCompilationErrors
 ;      Returns a buffer containing any error messages which occurred during
 ;      compile.  Or NULL if you do not care about the error messages.
 ;
 ;----------------------------------------------------------------------------
;API
D3DXCreateEffectFromFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateEffectFromFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateEffectFromFile	equ	<D3DXCreateEffectFromFileW>
ELSE
D3DXCreateEffectFromFile	equ	<D3DXCreateEffectFromFileA>
ENDIF 
;API
D3DXCreateEffectFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateEffectFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateEffectFromResource	equ	<D3DXCreateEffectFromResourceW>
ELSE
D3DXCreateEffectFromResource	equ	<D3DXCreateEffectFromResourceA>
ENDIF 
;API
D3DXCreateEffect PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXCreateEffectCompiler:
 ; -------------------------
 ; Creates an effect from an ascii or binary effect description.
 ;
 ; Parameters:
 ;  pSrcFile
 ;      Name of the file containing the effect description
 ;  hSrcModule
 ;      Module handle. if NULL, current module will be used.
 ;  pSrcResource
 ;      Resource name in module
 ;  pSrcData
 ;      Pointer to effect description
 ;  SrcDataSize
 ;      Size of the effect description in bytes
 ;  pDefines
 ;      Optional NULL-terminated array of preprocessor macro definitions.
 ;  pInclude
 ;      Optional interface pointer to use for handling #include directives.
 ;      If this parameter is NULL, #includes will be honored when compiling
 ;      from file, and will error when compiling from resource or memory.
 ;  pPool
 ;      Pointer to ID3DXEffectPool object to use for shared parameters.
 ;      If NULL, no parameters will be shared.
 ;  ppCompiler
 ;      Returns a buffer containing created effect compiler.
 ;  ppParseErrors
 ;      Returns a buffer containing any error messages which occurred during
 ;      parse.  Or NULL if you do not care about the error messages.
 ;
 ;----------------------------------------------------------------------------
;API
D3DXCreateEffectCompilerFromFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateEffectCompilerFromFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateEffectCompilerFromFile	equ	<D3DXCreateEffectCompilerFromFileW>
ELSE
D3DXCreateEffectCompilerFromFile	equ	<D3DXCreateEffectCompilerFromFileA>
ENDIF 
;API
D3DXCreateEffectCompilerFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateEffectCompilerFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateEffectCompilerFromResource	equ	<D3DXCreateEffectCompilerFromResourceW>
ELSE
D3DXCreateEffectCompilerFromResource	equ	<D3DXCreateEffectCompilerFromResourceA>
ENDIF 
;API
D3DXCreateEffectCompiler PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
ENDIF  ;__D3DX9EFFECT_H__
