 ;////////////////////////////////////////////////////////////////////////////
 ;
 ;  Copyright (c) Microsoft Corporation.  All rights reserved.
 ;
 ;  File:       d3dx9shader.h
 ;  Content:    D3DX Shader APIs
 ;
 ;////////////////////////////////////////////////////////////////////////////
IFNDEF __D3DX9_H__
INCLUDE d3dx9.INC
ENDIF
IFNDEF __D3DX9SHADER_H__
__D3DX9SHADER_H__ equ
 ;---------------------------------------------------------------------------
 ; D3DXTX_VERSION:
 ; --------------
 ; Version token used to create a procedural texture filler in effects
 ; Used by D3DXFill[]TX functions
 ;---------------------------------------------------------------------------
 ;----------------------------------------------------------------------------
 ; D3DXSHADER flags:
 ; -----------------
 ; D3DXSHADER_DEBUG
 ;   Insert debug file/line/type/symbol information.
 ;
 ; D3DXSHADER_SKIPVALIDATION
 ;   Do not validate the generated code against known capabilities and
 ;   constraints.  This option is only recommended when compiling shaders
 ;   you KNOW will work.  (ie. have compiled before without this option.)
 ;   Shaders are always validated by D3D before they are set to the device.
 ;
 ; D3DXSHADER_SKIPOPTIMIZATION (valid for D3DXCompileShader calls only)
 ;   Instructs the compiler to skip optimization steps during code generation.
 ;   Unless you are trying to isolate a problem in your code, and suspect the
 ;   compiler, using this option is not recommended.
 ;
 ; D3DXSHADER_PACKMATRIX_ROWMAJOR
 ;   Unless explicitly specified, matrices will be packed in row-major order
 ;   on input and output from the shader.
 ;
 ; D3DXSHADER_PACKMATRIX_COLUMNMAJOR
 ;   Unless explicitly specified, matrices will be packed in column-major
 ;   order on input and output from the shader.  This is generally more
 ;   efficient, since it allows vector-matrix multiplication to be performed
 ;   using a series of dot-products.
 ;----------------------------------------------------------------------------
D3DXSHADER_DEBUG	equ	<1 SHL  0>
D3DXSHADER_SKIPVALIDATION	equ	<1 SHL  2>
D3DXSHADER_SKIPOPTIMIZATION	equ	<1 SHL  3>
D3DXSHADER_PACKMATRIX_ROWMAJOR	equ	<1 SHL  4>
D3DXSHADER_PACKMATRIX_COLUMNMAJOR	equ	<1 SHL  5>
 ;----------------------------------------------------------------------------
 ; D3DXHANDLE:
 ; -----------
 ; Handle values used to efficiently reference shader and effect parameters.
 ; Strings can be used as handles.  However, handles are not always strings.
 ;----------------------------------------------------------------------------
 ;----------------------------------------------------------------------------
 ; D3DXMACRO:
 ; ----------
 ; Preprocessor macro definition.  The application pass in a NULL-terminated
 ; array of this structure to various D3DX APIs.  This enables the application
 ; to #define tokens at runtime, before the file is parsed.
 ;----------------------------------------------------------------------------

D3DXMACRO	STRUCT
	Name1 DWORD ?
	Definition DWORD ?

D3DXMACRO		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXSEMANTIC:
 ;----------------------------------------------------------------------------

D3DXSEMANTIC	STRUCT
	Usage DWORD ?
	UsageIndex DWORD ?

D3DXSEMANTIC		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXFRAGMENT_DESC:
 ;----------------------------------------------------------------------------

D3DXFRAGMENT_DESC	STRUCT
	Name1 DWORD ?
	Target DWORD ?

D3DXFRAGMENT_DESC		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXREGISTER_SET:
 ;----------------------------------------------------------------------------

;D3DXREGISTER_SET	UNION
	D3DXRS_BOOL	EQU 0H
	D3DXRS_INT4	EQU 01H
	D3DXRS_FLOAT4	EQU 02H
	D3DXRS_SAMPLER	EQU 03H
	D3DXRS_FORCE_DWORD	EQU 07fffffffh 
;D3DXREGISTER_SET		ENDS


 ;----------------------------------------------------------------------------
 ; D3DXPARAMETER_CLASS:
 ;----------------------------------------------------------------------------

;D3DXPARAMETER_CLASS	UNION
	D3DXPC_SCALAR	EQU 0H
	D3DXPC_VECTOR	EQU 01H
	D3DXPC_MATRIX_ROWS	EQU 02H
	D3DXPC_MATRIX_COLUMNS	EQU 03H
	D3DXPC_OBJECT	EQU 04H
	D3DXPC_STRUCT	EQU 05H
	D3DXPC_FORCE_DWORD	EQU 07fffffffh 
;D3DXPARAMETER_CLASS		ENDS


 ;----------------------------------------------------------------------------
 ; D3DXPARAMETER_TYPE:
 ;----------------------------------------------------------------------------

;D3DXPARAMETER_TYPE	UNION
	D3DXPT_VOID	EQU 0H
	D3DXPT_BOOL	EQU 01H
	D3DXPT_INT	EQU 02H
	D3DXPT_FLOAT	EQU 03H
	D3DXPT_STRING	EQU 04H
	D3DXPT_TEXTURE	EQU 05H
	D3DXPT_TEXTURE1D	EQU 06H
	D3DXPT_TEXTURE2D	EQU 07H
	D3DXPT_TEXTURE3D	EQU 08H
	D3DXPT_TEXTURECUBE	EQU 09H
	D3DXPT_SAMPLER	EQU 0AH
	D3DXPT_SAMPLER1D	EQU 0BH
	D3DXPT_SAMPLER2D	EQU 0CH
	D3DXPT_SAMPLER3D	EQU 0DH
	D3DXPT_SAMPLERCUBE	EQU 0EH
	D3DXPT_PIXELSHADER	EQU 0FH
	D3DXPT_VERTEXSHADER	EQU 010H
	D3DXPT_PIXELFRAGMENT	EQU 011H
	D3DXPT_VERTEXFRAGMENT	EQU 012H
	D3DXPT_FORCE_DWORD	EQU 07fffffffh 
;D3DXPARAMETER_TYPE		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXCONSTANTTABLE_DESC:
 ;----------------------------------------------------------------------------

D3DXCONSTANTTABLE_DESC	STRUCT
	Creator DWORD ?  ; Creator string
	Version DWORD ?  ; Shader version
	Constants DWORD ?  ; Number of constants

D3DXCONSTANTTABLE_DESC		ENDS

 ;----------------------------------------------------------------------------
 ; D3DXCONSTANT_DESC:
 ;----------------------------------------------------------------------------

D3DXCONSTANT_DESC	STRUCT
	Name1 DWORD ?  ; Constant name
	RegisterSet DWORD ?  ; Register set
	RegisterIndex DWORD ?  ; Register index
	RegisterCount DWORD ?  ; Number of registers occupied
	Class DWORD ?  ; Class
	type1 DWORD ?  ; Component type
	Rows DWORD ?  ; Number of rows
	Columns DWORD ?  ; Number of columns
	Elements DWORD ?  ; Number of array elements
	StructMembers DWORD ?  ; Number of structure member sub-parameters
	Bytes DWORD ?  ; Data size, in bytes
	DefaultValue DWORD ?  ; Pointer to default value

D3DXCONSTANT_DESC		ENDS

 ;----------------------------------------------------------------------------
 ; ID3DXConstantTable:
 ;----------------------------------------------------------------------------
 ; {9DCA3190-38B9-4fc3-92E3-39C6DDFB358B}
sIID_ID3DXConstantTable	TEXTEQU	<{09dca3190h,038b9h,04fc3h,(092h,0e3h,039h,0c6h,0ddh,0fbh,035h,08bh}}>
INTERFACE	equ	<ID3DXConstantTable>
;ID3DXConstantTable drive de : ID3DXBuffer
	STID3DXConstantTable	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetBufferPointer             	comethod1 ?
		GetBufferSize                	comethod1 ?
		GetDesc                      	comethod2 ?
		GetConstantDesc              	comethod4 ?
		GetConstant                  	comethod3 ?
		GetConstantByName            	comethod3 ?
		GetConstantElement           	comethod3 ?
		SetDefaults                  	comethod2 ?
		SetValue                     	comethod5 ?
		SetBool                      	comethod4 ?
		SetBoolArray                 	comethod5 ?
		SetInt                       	comethod4 ?
		SetIntArray                  	comethod5 ?
		SetFloat                     	comethod4 ?
		SetFloatArray                	comethod5 ?
		SetVector                    	comethod4 ?
		SetVectorArray               	comethod5 ?
		SetMatrix                    	comethod4 ?
		SetMatrixArray               	comethod5 ?
		SetMatrixPointerArray        	comethod5 ?
		SetMatrixTranspose           	comethod4 ?
		SetMatrixTransposeArray      	comethod5 ?
		SetMatrixTransposePointerArray 	comethod5 ?
	STID3DXConstantTable	ENDS
 
ID3DXConstantTable MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXConstantTable PTR[edx]).>,<&Function,ppvID3DXConstantTable>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXConstantTable
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;----------------------------------------------------------------------------
 ; ID3DXFragmentLinker
 ;----------------------------------------------------------------------------
INTERFACE	equ	<ID3DXFragmentLinker>
 ; {D59D3777-C973-4a3c-B4B0-2A62CD3D8B40}
sIID_ID3DXFragmentLinker	TEXTEQU	<{0d59d3777h,0c973h,04a3ch,(0b4h,0b0h,02ah,062h,0cdh,03dh,08bh,040h}}>
;ID3DXFragmentLinker drive de : IUnknown
	STID3DXFragmentLinker	STRUCT
		QueryInterface               	comethod3 ?
		AddRef                       	comethod1 ?
		Release                      	comethod1 ?
		GetDevice                    	comethod2 ?
		GetNumberOfFragments         	comethod1 ?
		GetFragmentHandleByIndex     	comethod2 ?
		GetFragmentHandleByName      	comethod2 ?
		GetFragmentDesc              	comethod3 ?
		AddFragments                 	comethod2 ?
		GetAllFragments              	comethod2 ?
		GetFragment                  	comethod3 ?
		LinkShader                   	comethod7 ?
		LinkVertexShader             	comethod7 ?
		ClearCache                   	comethod1 ?
	STID3DXFragmentLinker	ENDS
 
ID3DXFragmentLinker MACRO  Function:REQ, args:VARARG
	; definition de la macro locale InvokeInterface
    LOCAL InvokeInterface, arg
    FOR arg, <args>     ;verifier que edx n'est pas dans la liste d'arguments args
        IFIDNI <&arg>, <edx>	;
            .ERR <edx is not allowed as a coinvoke parameter>
        ENDIF
    ENDM
    IFIDNI <&pInterface>, <edx>
        .ERR <edx is not allowed as a coinvoke parameter>
    ENDIF
	;InvokeInterface = concatene ...CATSTR(concatene) MACRO instruction MASM32	
	;---------- on doit mettre ppv en premier argument -----------------------------------
    InvokeInterface CATSTR <invoke (STID3DXFragmentLinker PTR[edx]).>,<&Function,ppvID3DXFragmentLinker>
    IFNB <args>     ; add the list of parameter arguments if any
        InvokeInterface CATSTR InvokeInterface, <, >, <&args> 
    ENDIF 
	;   forme les lignes de codes
    mov edx, ppvID3DXFragmentLinker
    mov edx, [edx]
    InvokeInterface
ENDM		
 
 
 ;----------------------------------------------------------------------------
 ; D3DXINCLUDE_TYPE:
 ;----------------------------------------------------------------------------

;D3DXINCLUDE_TYPE	UNION
	D3DXINC_LOCAL	EQU 0H
	D3DXINC_SYSTEM	EQU 01H
	D3DXINC_FORCE_DWORD	EQU 07fffffffh 
;D3DXINCLUDE_TYPE		ENDS


 ;----------------------------------------------------------------------------
 ; ID3DXInclude:
 ; -------------
 ; This interface is intended to be implemented by the application, and can
 ; be used by various D3DX APIs.  This enables application-specific handling
 ; of #include directives in source files.
 ;
 ; Open()
 ;    Opens an include file.  If successful, it should fill in ppData and
 ;    pBytes.  The data pointer returned must remain valid until Close is
 ;    subsequently called.
 ; Close()
 ;    Closes an include file.  If Open was successful, Close is guaranteed
 ;    to be called before the API using this interface returns.
 ;----------------------------------------------------------------------------
INTERFACE	equ	<ID3DXInclude>
 ;////////////////////////////////////////////////////////////////////////////
 ; APIs //////////////////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;----------------------------------------------------------------------------
 ; D3DXAssembleShader:
 ; -------------------
 ; Assembles a shader.
 ;
 ; Parameters:
 ;  pSrcFile
 ;      Source file name
 ;  hSrcModule
 ;      Module handle. if NULL, current module will be used
 ;  pSrcResource
 ;      Resource name in module
 ;  pSrcData
 ;      Pointer to source code
 ;  SrcDataLen
 ;      Size of source code, in bytes
 ;  pDefines
 ;      Optional NULL-terminated array of preprocessor macro definitions.
 ;  pInclude
 ;      Optional interface pointer to use for handling #include directives.
 ;      If this parameter is NULL, #includes will be honored when assembling
 ;      from file, and will error when assembling from resource or memory.
 ;  Flags
 ;      See D3DXSHADER_xxx flags
 ;  ppShader
 ;      Returns a buffer containing the created shader.  This buffer contains
 ;      the assembled shader code, as well as any embedded debug info.
 ;      (See D3DXGetShaderDebugInfo)
 ;  ppErrorMsgs
 ;      Returns a buffer containing a listing of errors and warnings that were
 ;      encountered during assembly.  If you are running in a debugger,
 ;      these are the same messages you will see in your debug output.
 ;----------------------------------------------------------------------------
;API
D3DXAssembleShaderFromFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXAssembleShaderFromFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXAssembleShaderFromFile	equ	<D3DXAssembleShaderFromFileW>
ELSE
D3DXAssembleShaderFromFile	equ	<D3DXAssembleShaderFromFileA>
ENDIF 
;API
D3DXAssembleShaderFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXAssembleShaderFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXAssembleShaderFromResource	equ	<D3DXAssembleShaderFromResourceW>
ELSE
D3DXAssembleShaderFromResource	equ	<D3DXAssembleShaderFromResourceA>
ENDIF 
;API
D3DXAssembleShader PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXCompileShader:
 ; ------------------
 ; Compiles a shader.
 ;
 ; Parameters:
 ;  pSrcFile
 ;      Source file name.
 ;  hSrcModule
 ;      Module handle. if NULL, current module will be used.
 ;  pSrcResource
 ;      Resource name in module.
 ;  pSrcData
 ;      Pointer to source code.
 ;  SrcDataLen
 ;      Size of source code, in bytes.
 ;  pDefines
 ;      Optional NULL-terminated array of preprocessor macro definitions.
 ;  pInclude
 ;      Optional interface pointer to use for handling #include directives.
 ;      If this parameter is NULL, #includes will be honored when compiling
 ;      from file, and will error when compiling from resource or memory.
 ;  pFunctionName
 ;      Name of the entrypoint function where execution should begin.
 ;  pTarget
 ;      Instruction set to be used when generating code.  Currently supported
 ;      targets are "vs_1_1", "vs_2_0", "vs_2_sw", "ps_1_1", "ps_1_2", "ps_1_3",
 ;      "ps_1_4", "ps_2_0", "ps_2_sw", "tx_1_0"
 ;  Flags
 ;      See D3DXSHADER_xxx flags.
 ;  ppShader
 ;      Returns a buffer containing the created shader.  This buffer contains
 ;      the compiled shader code, as well as any embedded debug and symbol
 ;      table info.  (See D3DXGetShaderDebugInfo, D3DXGetShaderConstantTable)
 ;  ppErrorMsgs
 ;      Returns a buffer containing a listing of errors and warnings that were
 ;      encountered during the compile.  If you are running in a debugger,
 ;      these are the same messages you will see in your debug output.
 ;  ppConstantTable
 ;      Returns a ID3DXConstantTable object which can be used to set
 ;      shader constants to the device.  Alternatively, an application can
 ;      parse the D3DXSHADER_CONSTANTTABLE block embedded as a comment within
 ;      the shader.
 ;----------------------------------------------------------------------------
;API
D3DXCompileShaderFromFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCompileShaderFromFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCompileShaderFromFile	equ	<D3DXCompileShaderFromFileW>
ELSE
D3DXCompileShaderFromFile	equ	<D3DXCompileShaderFromFileA>
ENDIF 
;API
D3DXCompileShaderFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCompileShaderFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCompileShaderFromResource	equ	<D3DXCompileShaderFromResourceW>
ELSE
D3DXCompileShaderFromResource	equ	<D3DXCompileShaderFromResourceA>
ENDIF 
;API
D3DXCompileShader PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXFindShaderComment:
 ; ----------------------
 ; Searches through a shader for a particular comment, denoted by a FourCC in
 ; the first DWORD of the comment.  If the comment is not found, and no other
 ; error has occurred, S_FALSE is returned.
 ;
 ; Parameters:
 ;  pFunction
 ;      Pointer to the function DWORD stream
 ;  FourCC
 ;      FourCC used to identify the desired comment block.
 ;  ppData
 ;      Returns a pointer to the comment data (not including comment token
 ;      and FourCC).  Can be NULL.
 ;  pSizeInBytes
 ;      Returns the size of the comment data in bytes.  Can be NULL.
 ;----------------------------------------------------------------------------
;API
D3DXFindShaderComment PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXGetShaderSemantics:
 ; -----------------------
 ; Gets semantics for all input elements referenced inside a given shader.
 ;
 ; Parameters:
 ;  pFunction
 ;      Pointer to the function DWORD stream
 ;  pSemantics
 ;      Pointer to an array of D3DXSEMANTIC structures.  The function will
 ;      fill this array with the semantics for each input element referenced
 ;      inside the shader.  This array is assumed to contain at least
 ;      MAXD3DDECLLENGTH elements.
 ;  pCount
 ;      Returns the number of elements referenced by the shader
 ;----------------------------------------------------------------------------
;API
D3DXGetShaderInputSemantics PROTO :DWORD ,:DWORD ,:DWORD 
;API
D3DXGetShaderOutputSemantics PROTO :DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXGetShaderSamplers:
 ; ----------------------
 ; Gets semantics for all input elements referenced inside a given shader.
 ;
 ; pFunction
 ;      Pointer to the function DWORD stream
 ; pSamplers
 ;      Pointer to an array of LPCSTRs.  The function will fill this array
 ;      with pointers to the sampler names contained within pFunction, for
 ;      each sampler referenced inside the shader.  This array is assumed to
 ;      contain at least 16 elements.
 ; pCount
 ;      Returns the number of samplers referenced by the shader
 ;----------------------------------------------------------------------------
;API
D3DXGetShaderSamplers PROTO :DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXGetShaderConstantTable:
 ; ---------------------------
 ; Gets shader constant table embedded inside shader.  A constant table is
 ; generated by D3DXAssembleShader and D3DXCompileShader, and is embedded in
 ; the body of the shader.
 ;
 ; Parameters:
 ;  pFunction
 ;      Pointer to the function DWORD stream
 ;  ppConstantTable
 ;      Returns a ID3DXConstantTable object which can be used to set
 ;      shader constants to the device.  Alternatively, an application can
 ;      parse the D3DXSHADER_CONSTANTTABLE block embedded as a comment within
 ;      the shader.
 ;----------------------------------------------------------------------------
;API
D3DXGetShaderConstantTable PROTO :DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXGetShaderDebugInfo:
 ; -----------------------
 ; Gets shader debug info.  Debug info is generated D3DXAssembleShader and
 ; D3DXCompileShader and is embedded the body of the shader.
 ;
 ; Parameters:
 ;  pFunction
 ;      Pointer to the function DWORD stream
 ;  ppDebugInfo
 ;      Buffer used to return debug info.  For information about the layout
 ;      of this buffer, see definition of D3DXSHADER_DEBUGINFO above.
 ;----------------------------------------------------------------------------
;API
D3DXGetShaderDebugInfo PROTO :DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXGatherFragments:
 ; -------------------
 ; Assembles shader fragments into a buffer to be passed to a fragment linker.
 ;   will generate shader fragments for all fragments in the file
 ;
 ; Parameters:
 ;  pSrcFile
 ;      Source file name
 ;  hSrcModule
 ;      Module handle. if NULL, current module will be used
 ;  pSrcResource
 ;      Resource name in module
 ;  pSrcData
 ;      Pointer to source code
 ;  SrcDataLen
 ;      Size of source code, in bytes
 ;  pDefines
 ;      Optional NULL-terminated array of preprocessor macro definitions.
 ;  pInclude
 ;      Optional interface pointer to use for handling #include directives.
 ;      If this parameter is NULL, #includes will be honored when assembling
 ;      from file, and will error when assembling from resource or memory.
 ;  Flags
 ;      See D3DXSHADER_xxx flags
 ;  ppShader
 ;      Returns a buffer containing the created shader fragments.  This buffer contains
 ;      the assembled shader code, as well as any embedded debug info.
 ;  ppErrorMsgs
 ;      Returns a buffer containing a listing of errors and warnings that were
 ;      encountered during assembly.  If you are running in a debugger,
 ;      these are the same messages you will see in your debug output.
 ;----------------------------------------------------------------------------
;API
D3DXGatherFragmentsFromFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXGatherFragmentsFromFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXGatherFragmentsFromFile	equ	<D3DXGatherFragmentsFromFileW>
ELSE
D3DXGatherFragmentsFromFile	equ	<D3DXGatherFragmentsFromFileA>
ENDIF 
;API
D3DXGatherFragmentsFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXGatherFragmentsFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXGatherFragmentsFromResource	equ	<D3DXGatherFragmentsFromResourceW>
ELSE
D3DXGatherFragmentsFromResource	equ	<D3DXGatherFragmentsFromResourceA>
ENDIF 
;API
D3DXGatherFragments PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXCreateFragmentLinker:
 ; -------------------------
 ; Creates a fragment linker with a given cache size.  The interface returned
 ; can be used to link together shader fragments.  (both HLSL & ASM fragements)
 ;
 ; Parameters:
 ;  pDevice
 ;      Pointer of the device on which to create the effect
 ;  ShaderCacheSize
 ;      Size of the shader cache
 ;  ppFragmentLinker
 ;      pointer to a memory location to put the created interface pointer
 ;
 ;----------------------------------------------------------------------------
;API
D3DXCreateFragmentLinker PROTO :DWORD ,:DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;////////////////////////////////////////////////////////////////////////////
 ; Shader comment block layouts //////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ;----------------------------------------------------------------------------
 ; D3DXSHADER_CONSTANTTABLE:
 ; -------------------------
 ; Shader constant information; included as an CTAB comment block inside
 ; shaders.  All offsets are BYTE offsets from start of CONSTANTTABLE struct.
 ; Entries in the table are sorted by Name in ascending order.
 ;----------------------------------------------------------------------------

D3DXSHADER_CONSTANTTABLE	STRUCT
	size1 DWORD ?  ; sizeof(D3DXSHADER_CONSTANTTABLE)
	Creator DWORD ?  ; LPCSTR offset
	Version DWORD ?  ; shader version
	Constants DWORD ?  ; number of constants
	ConstantInfo DWORD ?  ; D3DXSHADER_CONSTANTINFO[Constants] offset

D3DXSHADER_CONSTANTTABLE		ENDS


D3DXSHADER_CONSTANTINFO	STRUCT
	Name1 DWORD ?  ; LPCSTR offset
	RegisterSet WORD ?  ; D3DXREGISTER_SET
	RegisterIndex WORD ?  ; register number
	RegisterCount WORD ?  ; number of registers
	Reserved WORD ?  ; reserved
	TypeInfo DWORD ?  ; D3DXSHADER_TYPEINFO offset
	DefaultValue DWORD ?  ; offset of default value

D3DXSHADER_CONSTANTINFO		ENDS


D3DXSHADER_TYPEINFO	STRUCT
	Class WORD ?  ; D3DXPARAMETER_CLASS
	type1 WORD ?  ; D3DXPARAMETER_TYPE
	Rows WORD ?  ; number of rows (matrices)
	Columns WORD ?  ; number of columns (vectors and matrices)
	Elements WORD ?  ; array dimension
	StructMembers WORD ?  ; number of struct members
	StructMemberInfo DWORD ?  ; D3DXSHADER_STRUCTMEMBERINFO[Members] offset

D3DXSHADER_TYPEINFO		ENDS


D3DXSHADER_STRUCTMEMBERINFO	STRUCT
	Name1 DWORD ?  ; LPCSTR offset
	TypeInfo DWORD ?  ; D3DXSHADER_TYPEINFO offset

D3DXSHADER_STRUCTMEMBERINFO		ENDS

ENDIF  ;__D3DX9SHADER_H__
