 ;/////////////////////////////////////////////////////////////////////////
 ;
 ;  Copyright (C) Microsoft Corporation.  All Rights Reserved.
 ;
 ;  File:       d3dx9shapes.h
 ;  Content:    D3DX simple shapes
 ;
 ;/////////////////////////////////////////////////////////////////////////
IFNDEF __D3DX9_H__
INCLUDE d3dx9.INC
ENDIF

IFNDEF __D3DX9SHAPES_H__
__D3DX9SHAPES_H__ equ
 ;/////////////////////////////////////////////////////////////////////////
 ; Functions:
 ;/////////////////////////////////////////////////////////////////////////

 ;-------------------------------------------------------------------------
 ; D3DXCreatePolygon:
 ; ------------------
 ; Creates a mesh containing an n-sided polygon.  The polygon is centered
 ; at the origin.
 ;
 ; Parameters:
 ;
 ;  pDevice     The D3D device with which the mesh is going to be used.
 ;  Length      Length of each side.
 ;  Sides       Number of sides the polygon has.  (Must be >= 3)
 ;  ppMesh      The mesh object which will be created
 ;  ppAdjacency Returns a buffer containing adjacency info.  Can be NULL.
 ;-------------------------------------------------------------------------
;API
D3DXCreatePolygon PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;-------------------------------------------------------------------------
 ; D3DXCreateBox:
 ; --------------
 ; Creates a mesh containing an axis-aligned box.  The box is centered at
 ; the origin.
 ;
 ; Parameters:
 ;
 ;  pDevice     The D3D device with which the mesh is going to be used.
 ;  Width       Width of box (along X-axis)
 ;  Height      Height of box (along Y-axis)
 ;  Depth       Depth of box (along Z-axis)
 ;  ppMesh      The mesh object which will be created
 ;  ppAdjacency Returns a buffer containing adjacency info.  Can be NULL.
 ;-------------------------------------------------------------------------
;API
D3DXCreateBox PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;-------------------------------------------------------------------------
 ; D3DXCreateCylinder:
 ; -------------------
 ; Creates a mesh containing a cylinder.  The generated cylinder is
 ; centered at the origin, and its axis is aligned with the Z-axis.
 ;
 ; Parameters:
 ;
 ;  pDevice     The D3D device with which the mesh is going to be used.
 ;  Radius1     Radius at -Z end (should be >= 0.0f)
 ;  Radius2     Radius at +Z end (should be >= 0.0f)
 ;  Length      Length of cylinder (along Z-axis)
 ;  Slices      Number of slices about the main axis
 ;  Stacks      Number of stacks along the main axis
 ;  ppMesh      The mesh object which will be created
 ;  ppAdjacency Returns a buffer containing adjacency info.  Can be NULL.
 ;-------------------------------------------------------------------------
;API
D3DXCreateCylinder PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;-------------------------------------------------------------------------
 ; D3DXCreateSphere:
 ; -----------------
 ; Creates a mesh containing a sphere.  The sphere is centered at the
 ; origin.
 ;
 ; Parameters:
 ;
 ;  pDevice     The D3D device with which the mesh is going to be used.
 ;  Radius      Radius of the sphere (should be >= 0.0f)
 ;  Slices      Number of slices about the main axis
 ;  Stacks      Number of stacks along the main axis
 ;  ppMesh      The mesh object which will be created
 ;  ppAdjacency Returns a buffer containing adjacency info.  Can be NULL.
 ;-------------------------------------------------------------------------
;API
D3DXCreateSphere PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;-------------------------------------------------------------------------
 ; D3DXCreateTorus:
 ; ----------------
 ; Creates a mesh containing a torus.  The generated torus is centered at
 ; the origin, and its axis is aligned with the Z-axis.
 ;
 ; Parameters:
 ;
 ;  pDevice     The D3D device with which the mesh is going to be used.
 ;  InnerRadius Inner radius of the torus (should be >= 0.0f)
 ;  OuterRadius Outer radius of the torue (should be >= 0.0f)
 ;  Sides       Number of sides in a cross-section (must be >= 3)
 ;  Rings       Number of rings making up the torus (must be >= 3)
 ;  ppMesh      The mesh object which will be created
 ;  ppAdjacency Returns a buffer containing adjacency info.  Can be NULL.
 ;-------------------------------------------------------------------------
;API
D3DXCreateTorus PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;-------------------------------------------------------------------------
 ; D3DXCreateTeapot:
 ; -----------------
 ; Creates a mesh containing a teapot.
 ;
 ; Parameters:
 ;
 ;  pDevice     The D3D device with which the mesh is going to be used.
 ;  ppMesh      The mesh object which will be created
 ;  ppAdjacency Returns a buffer containing adjacency info.  Can be NULL.
 ;-------------------------------------------------------------------------
;API
D3DXCreateTeapot PROTO :DWORD ,:DWORD ,:DWORD 
 ;-------------------------------------------------------------------------
 ; D3DXCreateText:
 ; ---------------
 ; Creates a mesh containing the specified text using the font associated
 ; with the device context.
 ;
 ; Parameters:
 ;
 ;  pDevice       The D3D device with which the mesh is going to be used.
 ;  hDC           Device context, with desired font selected
 ;  pText         Text to generate
 ;  Deviation     Maximum chordal deviation from true font outlines
 ;  Extrusion     Amount to extrude text in -Z direction
 ;  ppMesh        The mesh object which will be created
 ;  pGlyphMetrics Address of buffer to receive glyph metric data (or NULL)
 ;-------------------------------------------------------------------------
;API
D3DXCreateTextA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateTextW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateText	equ	<D3DXCreateTextW>
ELSE
D3DXCreateText	equ	<D3DXCreateTextA>
ENDIF 
IFDEF __cplusplus
ENDIF  ;__cplusplus    
ENDIF  ;__D3DX9SHAPES_H__
